@@ -33,7 +33,6 @@ class JavaObject(ObjectDescription):
         package = self.env.temp_data.get('java:imports', dict()).get(target, None)
 
         if package:
-
             ref['java:imported'] = True
             ref['java:package'] = package
         else:
@@ -82,13 +81,13 @@ class JavaObject(ObjectDescription):
                 if typ:
                     target = target + '.' + typ.name
                     parts.append(nodes.Text('.', '.'))
-                else:
+                elif dim:
                     parts.append(nodes.Text(dim, dim))
 
             return parts
         else:
             type_repr = formatter.output_type(typ).build()
-            return nodes.Text(type_repr, type_repr)
+            return [nodes.Text(type_repr, type_repr)]
 
     def _build_type_node_list(self, types):
         parts = self._build_type_node(types[0])
